package com.persagy.dmp.rwd.migrate.dao;

import org.apache.ibatis.annotations.Param;

/**
 * 数字孪生 数据迁移dao
 * @author Charlie Yu
 * @date 2021-08-04
 */
public interface DigitalMigrateMapper {

    /**
     * 迁移类型定义数据
     * @param schema
     * @param groupCode
     */
    void migrateDefineType(@Param("schema") String schema, @Param("groupCode") String groupCode);

    /**
     * 迁移信息点定义数据
     * @param schema
     * @param groupCode
     */
    void migrateDefineInfo(@Param("schema") String schema, @Param("groupCode") String groupCode);

    /**
     * 迁移图定义数据
     * @param schema
     * @param groupCode
     */
    void migrateDefineGraph(@Param("schema") String schema, @Param("groupCode") String groupCode);

    /**
     * 迁移边定义数据
     * @param schema
     * @param groupCode
     */
    void migrateDefineRel(@Param("schema") String schema, @Param("groupCode") String groupCode);

    /**
     * 迁移对象数据
     * @param schema
     * @param groupCode
     * @param projectId
     */
    void migrateObject(@Param("schema") String schema, @Param("groupCode") String groupCode, @Param("projectId") String projectId);

    /**
     * 迁移关系数据
     * @param schema
     * @param groupCode
     * @param projectId
     */
    void migrateRelation(@Param("schema") String schema, @Param("groupCode") String groupCode, @Param("projectId") String projectId);

}
